pub struct MshParserError<I> {
pub backtrace: Vec<(I, MshParserErrorKind)>,
}Expand description
Error type returned by the crate when parsing fails
Fields
backtrace: Vec<(I, MshParserErrorKind)>Error backtrace that contains per level a reference into the input where the error ocurred and the corresponding error kind
Implementations
Sourceimpl<I> MshParserError<I>
impl<I> MshParserError<I>
Sourcepub fn begin_msh_errors(&self) -> impl Iterator<Item = &(I, MshParserErrorKind)>
pub fn begin_msh_errors(&self) -> impl Iterator<Item = &(I, MshParserErrorKind)>
Iterator that skips all errors in the beginning of the backtrace that are not actual MSH format errors (i.e. internal nom parser errors)
Sourcepub fn filter_msh_errors(
&self,
) -> impl Iterator<Item = &(I, MshParserErrorKind)>
pub fn filter_msh_errors( &self, ) -> impl Iterator<Item = &(I, MshParserErrorKind)>
Iterator over all errors in the backtrace that are actual MSH format errors (i.e. filters out all internal nom parser errors)
Sourcepub fn first_msh_error(&self) -> Option<MshParserErrorKind>
pub fn first_msh_error(&self) -> Option<MshParserErrorKind>
Returns the kind of the first error in the backtrace that is an actual MSH format error kind (i.e. skips internal nom parser errors)
Sourceimpl<I: Clone> MshParserError<I>
impl<I: Clone> MshParserError<I>
Sourcepub fn filtered_backtrace(&self) -> Vec<(I, MshParserErrorKind)>
pub fn filtered_backtrace(&self) -> Vec<(I, MshParserErrorKind)>
Returns a backtrace containing only the errors that are actual MSH format errors (i.e. without internal nom parser errors)